use schemars::JsonSchema;
use serde::{Deserialize, Serialize};

#[derive(Clone, Serialize, Deserialize, JsonSchema)]
pub struct Contact {
    pub first_name: String,
    pub last_name: String,
    pub email: String,
    pub phone: String,
}

#[derive(Clone, Serialize, Deserialize, JsonSchema)]
pub struct Address {
    pub line_1: String,
    pub line_2: Option<String>,
    pub city: String,
    pub postal_code: String,
    pub province: Option<String>,
    pub country: String,
}
